Drop-in replacement for do.call(rbind.xts, list) that binds a list
of sxts objects by rows in a single pass, avoiding the O(n^2) complexity
of pairwise merging. Coordinates and projection are taken from the first
element.
Drop-in replacement for do.call(rbind.xts, list) that binds a list
of sxts objects by rows in a single pass, avoiding the O(n^2) complexity
of pairwise merging. Coordinates and projection are taken from the first
element.